<?php
/**
 * Customizer active callbacks
 *
 * @package Theme Palace
 * @subpackage Blog Diary Pro
 * @since Blog Diary Pro 1.0.0
 */

if ( ! function_exists( 'blog_diary_pro_is_loader_enable' ) ) :
	/**
	 * Check if loader is enabled.
	 *
	 * @since Blog Diary Pro 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function blog_diary_pro_is_loader_enable( $control ) {
		return $control->manager->get_setting( 'blog_diary_pro_theme_options[loader_enable]' )->value();
	}
endif;

if ( ! function_exists( 'blog_diary_pro_is_breadcrumb_enable' ) ) :
	/**
	 * Check if breadcrumb is enabled.
	 *
	 * @since Blog Diary Pro 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function blog_diary_pro_is_breadcrumb_enable( $control ) {
		return $control->manager->get_setting( 'blog_diary_pro_theme_options[breadcrumb_enable]' )->value();
	}
endif;

if ( ! function_exists( 'blog_diary_pro_is_pagination_enable' ) ) :
	/**
	 * Check if pagination is enabled.
	 *
	 * @since Blog Diary Pro 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function blog_diary_pro_is_pagination_enable( $control ) {
		return $control->manager->get_setting( 'blog_diary_pro_theme_options[pagination_enable]' )->value();
	}
endif;

/**
 * Front Page Active Callbacks
 */

/**
 * Check if secondary nav section is enabled.
 *
 * @since Blog Diary Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function blog_diary_pro_is_secondary_nav_section_enable( $control ) {
	return ( $control->manager->get_setting( 'blog_diary_pro_theme_options[top_bar_nav_section_enable]' )->value() );
}

/**
 * Check if slider section is enabled.
 *
 * @since Blog Diary Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function blog_diary_pro_is_slider_section_enable( $control ) {
	return ( $control->manager->get_setting( 'blog_diary_pro_theme_options[slider_section_enable]' )->value() );
}

/**
 * Check if slider section content type is post.
 *
 * @since Blog Diary Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function blog_diary_pro_is_slider_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'blog_diary_pro_theme_options[slider_content_type]' )->value();
	return blog_diary_pro_is_slider_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if slider section content type is page.
 *
 * @since Blog Diary Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function blog_diary_pro_is_slider_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'blog_diary_pro_theme_options[slider_content_type]' )->value();
	return blog_diary_pro_is_slider_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if slider section content type is custom.
 *
 * @since Blog Diary Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function blog_diary_pro_is_slider_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'blog_diary_pro_theme_options[slider_content_type]' )->value();
	return blog_diary_pro_is_slider_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if featured slider section is enabled.
 *
 * @since Blog Diary Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function blog_diary_pro_is_featured_slider_section_enable( $control ) {
	return ( $control->manager->get_setting( 'blog_diary_pro_theme_options[featured_slider_section_enable]' )->value() );
}

/**
 * Check if latest_posts section is enabled.
 *
 * @since Blog Diary Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function blog_diary_pro_is_latest_posts_section_enable( $control ) {
	return ( $control->manager->get_setting( 'blog_diary_pro_theme_options[latest_posts_section_enable]' )->value() );
}

/**
 * Check if latest_posts section content type is post.
 *
 * @since Blog Diary Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function blog_diary_pro_is_latest_posts_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'blog_diary_pro_theme_options[latest_posts_content_type]' )->value();
	return blog_diary_pro_is_latest_posts_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if latest_posts section content type is page.
 *
 * @since Blog Diary Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function blog_diary_pro_is_latest_posts_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'blog_diary_pro_theme_options[latest_posts_content_type]' )->value();
	return blog_diary_pro_is_latest_posts_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if latest_posts section content type is custom.
 *
 * @since Blog Diary Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function blog_diary_pro_is_latest_posts_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'blog_diary_pro_theme_options[latest_posts_content_type]' )->value();
	return blog_diary_pro_is_latest_posts_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if must_read_posts section is enabled.
 *
 * @since Blog Diary Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function blog_diary_pro_is_must_read_posts_section_enable( $control ) {
	return ( $control->manager->get_setting( 'blog_diary_pro_theme_options[must_read_posts_section_enable]' )->value() );
}

/**
 * Check if must_read_posts section content type is post.
 *
 * @since Blog Diary Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function blog_diary_pro_is_must_read_posts_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'blog_diary_pro_theme_options[must_read_posts_content_type]' )->value();
	return blog_diary_pro_is_must_read_posts_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if must_read_posts section content type is page.
 *
 * @since Blog Diary Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function blog_diary_pro_is_must_read_posts_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'blog_diary_pro_theme_options[must_read_posts_content_type]' )->value();
	return blog_diary_pro_is_must_read_posts_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if must_read_posts section content type is custom.
 *
 * @since Blog Diary Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function blog_diary_pro_is_must_read_posts_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'blog_diary_pro_theme_options[must_read_posts_content_type]' )->value();
	return blog_diary_pro_is_must_read_posts_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if blog section is enabled.
 *
 * @since Blog Diary Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function blog_diary_pro_is_blog_section_enable( $control ) {
	return ( $control->manager->get_setting( 'blog_diary_pro_theme_options[blog_section_enable]' )->value() );
}

/**
 * Check if blog section content type is post.
 *
 * @since Blog Diary Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function blog_diary_pro_is_blog_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'blog_diary_pro_theme_options[blog_content_type]' )->value();
	return blog_diary_pro_is_blog_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if blog section content type is page.
 *
 * @since Blog Diary Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function blog_diary_pro_is_blog_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'blog_diary_pro_theme_options[blog_content_type]' )->value();
	return blog_diary_pro_is_blog_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if blog section content type is category.
 *
 * @since Blog Diary Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function blog_diary_pro_is_blog_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'blog_diary_pro_theme_options[blog_content_type]' )->value();
	return blog_diary_pro_is_blog_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if blog section content type is recent.
 *
 * @since Blog Diary Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function blog_diary_pro_is_blog_section_content_recent_enable( $control ) {
	$content_type = $control->manager->get_setting( 'blog_diary_pro_theme_options[blog_content_type]' )->value();
	return blog_diary_pro_is_blog_section_enable( $control ) && ( 'recent' == $content_type );
}
